@@ -4,7 +4,7 @@ import logging
 from tqdm import tqdm
 import pandas as pd
 
-from .optimize.policy import OptimizedWeightingPolicyUsingMPTSharpeRatio, OptimizedWeightingPolicyUsingMPTCostFunction
+from .optimize.policy import OptimizedWeightingPolicyUsingMPTSharpeRatio, OptimizedWeightingPolicyUsingMPTCostFunction, OptimizedWeightingPolicyUsingMPTEntropyCostFunction
 from .numerics import get_BlackScholesMerton_stocks_estimation
 from .numerics import get_symbol_closing_price
 from ..data.preader import get_yahoofinance_data
@@ -170,3 +170,28 @@ def get_optimized_portfolio_on_mpt_costfunction(
     optimized_weighting_policy = OptimizedWeightingPolicyUsingMPTCostFunction(rf, r, cov, symbols, lamb, V0=V0)
     optimized_portfolio = OptimizedPortfolio(optimized_weighting_policy, totalworth, presetdate, cacheddir=cacheddir)
     return optimized_portfolio
+
+
+def get_optimized_portfolio_on_mpt_entropy_costfunction(
+        rf,
+        symbols,
+        totalworth,
+        presetdate,
+        estimating_startdate,
+        estimating_enddate,
+        lamb0,
+        lamb1,
+        V=10.,
+        lazy=False,
+        cacheddir=None
+):
+    r, cov = get_BlackScholesMerton_stocks_estimation(
+        symbols,
+        estimating_startdate,
+        estimating_enddate,
+        lazy=lazy,
+        cacheddir=cacheddir
+    )
+    optimized_weighting_policy = OptimizedWeightingPolicyUsingMPTEntropyCostFunction(rf, r, cov, symbols, lamb0, lamb1, V=V)
+    optimized_portfolio = OptimizedPortfolio(optimized_weighting_policy, totalworth, presetdate, cacheddir=cacheddir)
+    return optimized_portfolio
